@@ -1,7 +1,10 @@
 package icon
 
 func InitIcon(nerdfont bool, directoryIconColor string) {
+	// Make sure that these alternatives are ASCII characters only.
+	// Dont place any special unicode characters here.
 	if !nerdfont {
+		// Do we need this to be empty ? Maybe it should just be normal space ?
 		Space = ""
 		SuperfileIcon = ""
 
@@ -23,22 +26,24 @@ func InitIcon(nerdfont bool, directoryIconColor string) {
 
 		// other
 		Cursor = ">"
-		Browser = ""
-		Select = ""
+		Browser = "B"
+		Select = "S"
 		Error = ""
 		Warn = ""
 		Done = ""
 		InOperation = ""
 		Directory = ""
 		Search = ""
-		SortAsc = ""
-		SortDesc = ""
+		SortAsc = "^"
+		SortDesc = "v"
+		Pinned = ""
+		Disk = ""
 	}
 
 	if directoryIconColor == "" {
 		directoryIconColor = "NONE" // Dark yellowish
 	}
-	Folders["folder"] = IconStyle{
+	Folders["folder"] = Style{
 		Icon:  "\uf07b", // Printable Rune : ""
 		Color: directoryIconColor,
 	}
