@@ -57,6 +57,9 @@ func returnFocusType(focusPanel focusPanelType) filePanelFocusType {
 	return secondFocus
 }
 
+// Todo : Take common.Config.CaseSensitiveSort as a function parameter
+// and also consider testing this caseSensitive with both true and false in
+// our unit_test TestReturnDirElement
 func returnDirElement(location string, displayDotFile bool, sortOptions sortOptionsModelData) []element {
 	dirEntries, err := os.ReadDir(location)
 	if err != nil {
@@ -129,6 +132,33 @@ func returnDirElement(location string, displayDotFile bool, sortOptions sortOpti
 			fileInfoJ, _ := dirEntries[j].Info()
 			return fileInfoI.ModTime().After(fileInfoJ.ModTime()) != reversed
 		}
+	case "Type":
+		order = func(i, j int) bool {
+			// One of them is a directory, and the other is not
+			if dirEntries[i].IsDir() != dirEntries[j].IsDir() {
+				return dirEntries[i].IsDir()
+			}
+
+			var extI, extJ string
+			if !dirEntries[i].IsDir() {
+				extI = strings.ToLower(filepath.Ext(dirEntries[i].Name()))
+			}
+			if !dirEntries[j].IsDir() {
+				extJ = strings.ToLower(filepath.Ext(dirEntries[j].Name()))
+			}
+
+			// Compare by extension/type
+			if extI != extJ {
+				return (extI < extJ) != reversed
+			}
+
+			// If same type, fall back to name
+			if common.Config.CaseSensitiveSort {
+				return (dirEntries[i].Name() < dirEntries[j].Name()) != reversed
+			}
+
+			return (strings.ToLower(dirEntries[i].Name()) < strings.ToLower(dirEntries[j].Name())) != reversed
+		}
 	}
 
 	sort.Slice(dirEntries, order)
