@@ -2,37 +2,43 @@ package internal
 
 import (
 	"log/slog"
+
+	"github.com/yorukot/superfile/src/internal/common"
 )
 
 func wheelMainAction(msg string, m *model) {
 	slog.Debug("wheelMainAction called", "msg", msg, "focusPanel", m.focusPanel)
 	var action func()
 	switch msg {
-
 	case "wheel up":
-		if m.focusPanel == sidebarFocus {
-			action = func() { m.sidebarModel.listUp(m.mainPanelHeight) }
-		} else if m.focusPanel == processBarFocus {
+		switch m.focusPanel {
+		case sidebarFocus:
+			action = func() { m.sidebarModel.ListUp(m.mainPanelHeight) }
+		case processBarFocus:
 			action = func() { m.processBarModel.listUp(m.footerHeight) }
-		} else if m.focusPanel == metadataFocus {
+		case metadataFocus:
 			action = func() { m.fileMetaData.listUp() }
-		} else if m.focusPanel == nonePanelFocus {
+		case nonePanelFocus:
 			action = func() { m.fileModel.filePanels[m.filePanelFocusIndex].listUp(m.mainPanelHeight) }
 		}
 
 	case "wheel down":
-		if m.focusPanel == sidebarFocus {
-			action = func() { m.sidebarModel.listDown(m.mainPanelHeight) }
-		} else if m.focusPanel == processBarFocus {
+		switch m.focusPanel {
+		case sidebarFocus:
+			action = func() { m.sidebarModel.ListDown(m.mainPanelHeight) }
+		case processBarFocus:
 			action = func() { m.processBarModel.listDown(m.footerHeight) }
-		} else if m.focusPanel == metadataFocus {
+		case metadataFocus:
 			action = func() { m.fileMetaData.listDown() }
-		} else if m.focusPanel == nonePanelFocus {
+		case nonePanelFocus:
 			action = func() { m.fileModel.filePanels[m.filePanelFocusIndex].listDown(m.mainPanelHeight) }
 		}
+	default:
+		slog.Error("Unexpected type of mouse action in wheelMainAction", "msg", msg)
+		return
 	}
 
-	for i := 0; i < wheelRunTime; i++ {
+	for range common.WheelRunTime {
 		action()
 	}
 
